==> gorm-1.2.12p3.tgz: include/InterfaceBuilder/InterfaceBuilder.h <==
/* InterfaceBuilder.h
 *
 * Copyright (C) 2003 Free Software Foundation, Inc.
 *
 * Author:	Gregory John Casamento <greg_casamento@yahoo.com>
 * Date:	2003
 * 
 * This file is part of GNUstep.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */

#ifndef INCLUDED_INTERFACEBUILDER_H
#define INCLUDED_INTERFACEBUIDLER_H
 
#include <InterfaceBuilder/IBApplicationAdditions.h>
#include <InterfaceBuilder/IBCellAdditions.h>
#include <InterfaceBuilder/IBCellProtocol.h>
#include <InterfaceBuilder/IBConnectors.h>
#include <InterfaceBuilder/IBDefines.h>
#include <InterfaceBuilder/IBDocuments.h>
#include <InterfaceBuilder/IBEditors.h>
#include <InterfaceBuilder/IBInspector.h>
#include <InterfaceBuilder/IBInspectorManager.h>
#include <InterfaceBuilder/IBObjectAdditions.h>
#include <InterfaceBuilder/IBObjectProtocol.h>
#include <InterfaceBuilder/IBPalette.h>
#include <InterfaceBuilder/IBPlugin.h>
#include <InterfaceBuilder/IBProjects.h>
#include <InterfaceBuilder/IBProjectFiles.h>
#include <InterfaceBuilder/IBResourceManager.h>
#include <InterfaceBuilder/IBSystem.h>
#include <InterfaceBuilder/IBViewAdditions.h>
#include <InterfaceBuilder/IBViewProtocol.h>
#include <InterfaceBuilder/IBViewResourceDragging.h>

#endif

==> gorm-1.2.22.tgz: include/InterfaceBuilder/InterfaceBuilder.h <==
/* InterfaceBuilder.h
 *
 * Copyright (C) 2003 Free Software Foundation, Inc.
 *
 * Author:	Gregory John Casamento <greg_casamento@yahoo.com>
 * Date:	2003
 * 
 * This file is part of GNUstep.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */

#ifndef INCLUDED_INTERFACEBUILDER_H
#define INCLUDED_INTERFACEBUILDER_H
 
#include <InterfaceBuilder/IBApplicationAdditions.h>
#include <InterfaceBuilder/IBCellAdditions.h>
#include <InterfaceBuilder/IBCellProtocol.h>
#include <InterfaceBuilder/IBConnectors.h>
#include <InterfaceBuilder/IBDefines.h>
#include <InterfaceBuilder/IBDocuments.h>
#include <InterfaceBuilder/IBEditors.h>
#include <InterfaceBuilder/IBInspector.h>
#include <InterfaceBuilder/IBInspectorManager.h>
#include <InterfaceBuilder/IBObjectAdditions.h>
#include <InterfaceBuilder/IBObjectProtocol.h>
#include <InterfaceBuilder/IBPalette.h>
#include <InterfaceBuilder/IBPlugin.h>
#include <InterfaceBuilder/IBProjects.h>
#include <InterfaceBuilder/IBProjectFiles.h>
#include <InterfaceBuilder/IBResourceManager.h>
#include <InterfaceBuilder/IBSystem.h>
#include <InterfaceBuilder/IBViewAdditions.h>
#include <InterfaceBuilder/IBViewProtocol.h>
#include <InterfaceBuilder/IBViewResourceDragging.h>

#endif
